@@ -45,6 +45,7 @@ majmin = (major, minor)
 version = (major, minor, micro)
 
 guidre = regex.compile('^[0-9a-f]{32}$')
+buidre = regex.compile('^[0-9a-f]{64}$')
 
 novalu = NoValu()
 
@@ -135,6 +136,9 @@ def uhex(text):
 def isguid(text):
     return guidre.match(text) is not None
 
+def isbuidhex(text):
+    return buidre.match(text) is not None
+
 def intify(x):
     '''
     Ensure ( or coerce ) a value into being an integer or None.
@@ -225,7 +229,7 @@ def reqpath(*paths):
     '''
     path = genpath(*paths)
     if not os.path.isfile(path):
-        raise s_exc.NoSuchFile(name=path)
+        raise s_exc.NoSuchFile(mesg=f'No such path {path}', path=path)
     return path
 
 def reqfile(*paths, **opts):
@@ -242,7 +246,7 @@ def reqfile(*paths, **opts):
     '''
     path = genpath(*paths)
     if not os.path.isfile(path):
-        raise s_exc.NoSuchFile(path=path)
+        raise s_exc.NoSuchFile(mesg=f'No such file {path}', path=path)
     opts.setdefault('mode', 'rb')
     return io.open(path, **opts)
 
@@ -461,7 +465,7 @@ def yamlsave(obj, *paths):
     path = genpath(*paths)
     with genfile(path) as fd:
         s = yaml.safe_dump(obj, allow_unicode=False, default_flow_style=False,
-                           default_style='', explicit_start=True, explicit_end=True)
+                           default_style='', explicit_start=True, explicit_end=True, sort_keys=True)
         fd.truncate(0)
         fd.write(s.encode('utf8'))
 
@@ -833,8 +837,8 @@ def config(conf, confdefs):
 
     return conf
 
-def deprecated(name):
-    mesg = f'"{name}" is deprecated in 2.x and will be removed in 3.0.0'
+def deprecated(name, curv='2.x', eolv='3.0.0'):
+    mesg = f'"{name}" is deprecated in {curv} and will be removed in {eolv}'
     warnings.warn(mesg, DeprecationWarning)
 
 def reqjsonsafe(item):
@@ -1023,3 +1027,29 @@ def getSslCtx(cadir, purpose=ssl.Purpose.SERVER_AUTH):
         except Exception:  # pragma: no cover
             logger.exception(f'Error loading {certpath}')
     return sslctx
+
+# TODO:  Remove when this is added to contextlib in py 3.10
+class aclosing(contextlib.AbstractAsyncContextManager):
+    """Async context manager for safely finalizing an asynchronously cleaned-up
+    resource such as an async generator, calling its ``aclose()`` method.
+
+    Code like this:
+
+        async with aclosing(<module>.fetch(<arguments>)) as agen:
+            <block>
+
+    is equivalent to this:
+
+        agen = <module>.fetch(<arguments>)
+        try:
+            <block>
+        finally:
+            await agen.aclose()
+
+    """
+    def __init__(self, thing):
+        self.thing = thing
+    async def __aenter__(self):
+        return self.thing
+    async def __aexit__(self, exc, cls, tb):
+        await self.thing.aclose()
