@@ -15,6 +15,7 @@ import synapse.exc as s_exc
 import synapse.common as s_common
 
 import synapse.lib.base as s_base
+import synapse.lib.coro as s_coro
 import synapse.lib.config as s_config
 import synapse.lib.provenance as s_provenance
 
@@ -323,9 +324,8 @@ class _Appt:
             raise s_exc.BadTime(mesg='A recurrent appointment with no records')
 
         if nexttime is None and self.recs:
-            now = time.time()
-            self.nexttime = now
-            self.updateNexttime(now + 1.0)  # lie slightly about the time so it does advance
+            self.nexttime = self.stor._getNowTick()
+            self.updateNexttime(self.nexttime)
             if self.nexttime is None:
                 raise s_exc.BadTime(mesg='Appointment is in the past')
         else:
@@ -471,11 +471,12 @@ class Agenda(s_base.Base):
         self.apptheap = []  # Stores the appointments in a heap such that the first element is the next appt to run
         self.appts = {}  # Dict[bytes: Appt]
         self._next_indx = 0  # index a new appt gets assigned
+        self.tickoff = 0  # Used for test overrides
 
-        self._wake_event = asyncio.Event()  # Causes the scheduler loop to wake up
+        self._wake_event = s_coro.Event()  # Causes the scheduler loop to wake up
         self.onfini(self._wake_event.set)
 
-        self._hivenode = await self.core.hive.open(('agenda', 'appts')) # Persistent storage
+        self._hivenode = await self.core.hive.open(('agenda', 'appts'))  # Persistent storage
         self.onfini(self.stop)
 
         self.enabled = False
@@ -499,7 +500,8 @@ class Agenda(s_base.Base):
             try:
                 await self.core.getStormQuery(appt.query)
             except Exception as e:
-                logger.warning('Invalid appointment %r found in storage: %r.  Disabling.', iden, e)
+                logger.exception(f'Invalid appointment {iden} {appt.name} found in storage. Disabling. {e}',
+                                 extra={'synapse': {'iden': iden, 'name': appt.name, 'text': appt.query}})
                 appt.enabled = False
 
         self._schedtask = self.schedCoro(self._scheduleLoop())
@@ -654,7 +656,7 @@ class Agenda(s_base.Base):
                 if incunit is not None:
                     mesg = "Recurring jobs may not be scheduled to run 'now'"
                     raise ValueError(mesg)
-                nexttime = time.time()
+                nexttime = self._getNowTick()
                 continue
 
             reqdicts = self._dictproduct(req)
@@ -752,22 +754,31 @@ class Agenda(s_base.Base):
         if node is not None:
             await node.hive.pop(node.full)
 
+    def _getNowTick(self):
+        return time.time() + self.tickoff
+
+    def _addTickOff(self, offs):
+        self.tickoff += offs
+        self._wake_event.set()
+
     async def _scheduleLoop(self):
         '''
         Task loop to issue query tasks at the right times.
         '''
         while True:
-            try:
-                timeout = None if not self.apptheap else self.apptheap[0].nexttime - time.time()
-                if timeout is None or timeout >= 0.0:
-                    await asyncio.wait_for(self._wake_event.wait(), timeout=timeout)
-            except asyncio.TimeoutError:
-                pass
+
+            timeout = None
+            if self.apptheap:
+                timeout = self.apptheap[0].nexttime - self._getNowTick()
+
+            if timeout is None or timeout > 0:
+                self._wake_event.clear()
+                await self._wake_event.timewait(timeout=timeout)
+
             if self.isfini:
                 return
-            self._wake_event.clear()
 
-            now = time.time()
+            now = self._getNowTick()
             while self.apptheap and self.apptheap[0].nexttime <= now:
 
                 appt = heapq.heappop(self.apptheap)
@@ -779,10 +790,11 @@ class Agenda(s_base.Base):
                 if not appt.enabled or not self.enabled:
                     continue
 
-                if appt.isrunning:
-                    logger.warning(
-                        'Appointment %s is still running from previous time when scheduled to run.  Skipping.',
-                        appt.iden)
+                if appt.isrunning:  # pragma: no cover
+                    mesg = f'Appointment {appt.iden} {appt.name} is still running from previous time when scheduled' \
+                           f' to run. Skipping.',
+                    logger.warning(mesg,
+                                   extra={'synapse': {'iden': appt.iden, 'name': appt.name}})
                 else:
                     await self._execute(appt)
 
@@ -792,19 +804,24 @@ class Agenda(s_base.Base):
         '''
         user = self.core.auth.user(appt.creator)
         if user is None:
-            logger.warning('Unknown user %s in stored appointment', appt.creator)
+            logger.warning(f'Unknown user {appt.creator} in stored appointment {appt.iden} {appt.name}',
+                           extra={'synapse': {'iden': appt.iden, 'name': appt.name, 'user': appt.creator}})
             await self._markfailed(appt, 'unknown user')
             return
 
         locked = user.info.get('locked')
         if locked:
-            logger.warning('Cron failed because creator %s is locked', user.name)
+            logger.warning(f'Cron {appt.iden} {appt.name} failed because creator {user.name} is locked',
+                           extra={'synapse': {'iden': appt.iden, 'name': appt.name, 'user': appt.creator,
+                                              'username': user.name}})
             await self._markfailed(appt, 'locked user')
             return
 
         view = self.core.getView(iden=appt.view, user=user)
         if view is None:
-            logger.warning('Unknown view %s in stored appointment', appt.view)
+            logger.warning(f'Unknown view {appt.view} in stored appointment {appt.iden} {appt.name}',
+                           extra={'synapse': {'iden': appt.iden, 'name': appt.name, 'user': appt.creator,
+                                              'username': user.name, 'view': appt.view}})
             await self._markfailed(appt, 'unknown view')
             return
 
@@ -815,7 +832,7 @@ class Agenda(s_base.Base):
         task.onfini(functools.partial(self._running_tasks.remove, task))
 
     async def _markfailed(self, appt, reason):
-        appt.lastfinishtime = appt.laststarttime = time.time()
+        appt.lastfinishtime = appt.laststarttime = self._getNowTick()
         appt.startcount += 1
         appt.isrunning = False
         appt.lastresult = f'Failed due to {reason}'
@@ -828,13 +845,15 @@ class Agenda(s_base.Base):
         '''
         count = 0
         appt.isrunning = True
-        appt.laststarttime = time.time()
+        appt.laststarttime = self._getNowTick()
         appt.startcount += 1
         await self._storeAppt(appt, nexs=True)
 
         with s_provenance.claim('cron', iden=appt.iden):
-            logger.info('Agenda executing for iden=%s, user=%s, view=%s, query={%s}', appt.iden, user.name, appt.view, appt.query)
-            starttime = time.time()
+            logger.info(f'Agenda executing for iden={appt.iden}, name={appt.name} user={user.name}, view={appt.view}, query={appt.query}',
+                        extra={'synapse': {'iden': appt.iden, 'name': appt.name, 'user': user.iden, 'text': appt.query,
+                                           'username': user.name, 'view': appt.view}})
+            starttime = self._getNowTick()
             success = False
             try:
                 opts = {'user': user.iden, 'view': appt.view}
@@ -845,17 +864,22 @@ class Agenda(s_base.Base):
                 raise
             except Exception as e:
                 result = f'raised exception {e}'
-                logger.exception('Agenda job %s raised exception', appt.iden)
+                logger.exception(f'Agenda job {appt.iden} {appt.name} raised exception',
+                                 extra={'synapse': {'iden': appt.iden, 'name': appt.name}}
+                                 )
             else:
                 success = True
                 result = f'finished successfully with {count} nodes'
             finally:
-                finishtime = time.time()
+                finishtime = self._getNowTick()
                 if not success:
                     appt.errcount += 1
                     appt.lasterrs.append(result)
-                logger.info('Agenda completed query for iden=%s with result "%s" took %0.3fs',
-                            appt.iden, result, finishtime - starttime)
+                took = finishtime - starttime
+                mesg = f'Agenda completed query for iden={appt.iden} name={appt.name} with result "{result}" ' \
+                       f'took {took:.3f}s'
+                logger.info(mesg, extra={'synapse': {'iden': appt.iden, 'name': appt.name, 'user': user.iden,
+                                                     'result': result, 'username': user.name, 'took': took}})
                 appt.lastfinishtime = finishtime
                 appt.isrunning = False
                 appt.lastresult = result
