@@ -370,16 +370,7 @@ class CellApi(s_base.Base):
 
     @adminapi()
     async def issue(self, nexsiden: str, event: str, args, kwargs, meta=None):
-        '''
-        Note:  this swallows exceptions and return values.  It is expected that the nexus _followerLoop would be the
-        return path
-        '''
-        try:
-            await self.cell.nexsroot.issue(nexsiden, event, args, kwargs, meta)
-        except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
-            raise
-        except Exception:
-            pass
+        return await self.cell.nexsroot.issue(nexsiden, event, args, kwargs, meta)
 
     @adminapi(log=True)
     async def delAuthUser(self, name):
@@ -684,7 +675,7 @@ class CellApi(s_base.Base):
         await self.cell.iterBackupArchive(name, user=self.user)
 
         # Make this a generator
-        if False: # pragma: no cover
+        if False:  # pragma: no cover
             yield
 
     @adminapi()
@@ -701,7 +692,7 @@ class CellApi(s_base.Base):
         await self.cell.iterNewBackupArchive(user=self.user, name=name, remove=remove)
 
         # Make this a generator
-        if False: # pragma: no cover
+        if False:  # pragma: no cover
             yield
 
     @adminapi()
@@ -1227,7 +1218,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
             proxy = await self.ahaclient.proxy(timeout=2)
 
-        except TimeoutError: # pragma: no cover
+        except TimeoutError:  # pragma: no cover
             return None
 
         # if we went inactive, bump the aha proxy
@@ -1238,9 +1229,9 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         ahanetw = self.conf.get('aha:network')
         try:
             await proxy.addAhaSvc(ahalead, self.ahainfo, network=ahanetw)
-        except asyncio.CancelledError: # pragma: no cover
+        except asyncio.CancelledError:  # pragma: no cover
             raise
-        except Exception as e: # pragma: no cover
+        except Exception as e:  # pragma: no cover
             logger.warning(f'_setAhaActive failed: {e}')
 
     def addActiveCoro(self, func, iden=None, base=None):
@@ -1338,10 +1329,10 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
         await self._setAhaActive()
 
-    async def initServiceActive(self): # pragma: no cover
+    async def initServiceActive(self):  # pragma: no cover
         pass
 
-    async def initServicePassive(self): # pragma: no cover
+    async def initServicePassive(self):  # pragma: no cover
         pass
 
     async def getNexusChanges(self, offs):
@@ -1841,11 +1832,14 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
     async def getAuthRoles(self):
         return [r.pack() for r in self.auth.roles()]
 
-    async def dyniter(self, iden, todo, gatekeys=()):
-
+    async def reqGateKeys(self, gatekeys):
         for useriden, perm, gateiden in gatekeys:
             (await self.auth.reqUser(useriden)).confirm(perm, gateiden=gateiden)
 
+    async def dyniter(self, iden, todo, gatekeys=()):
+
+        await self.reqGateKeys(gatekeys)
+
         item = self.dynitems.get(iden)
         name, args, kwargs = todo
 
@@ -1855,8 +1849,7 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
 
     async def dyncall(self, iden, todo, gatekeys=()):
 
-        for useriden, perm, gateiden in gatekeys:
-            (await self.auth.reqUser(useriden)).confirm(perm, gateiden=gateiden)
+        await self.reqGateKeys(gatekeys)
 
         item = self.dynitems.get(iden)
         if item is None:
@@ -1924,10 +1917,10 @@ class Cell(s_nexus.Pusher, s_telepath.Aware):
         sslctx.minimum_version = ssl.TLSVersion.TLSv1_2
 
         if not os.path.isfile(keypath):
-            raise s_exc.NoSuchFile(name=keypath)
+            raise s_exc.NoSuchFile(mesg=f'Missing TLS keypath {keypath}', path=keypath)
 
         if not os.path.isfile(certpath):
-            raise s_exc.NoSuchFile(name=certpath)
+            raise s_exc.NoSuchFile(mesg=f'Missing TLS certpath {certpath}', path=certpath)
 
         sslctx.load_cert_chain(certpath, keypath)
         return sslctx
