@@ -5,6 +5,7 @@ import asyncio
 import hashlib
 import logging
 import unittest.mock as mock
+import tornado.httputil as t_httputil
 
 import aiohttp.client_exceptions as a_exc
 
@@ -33,6 +34,11 @@ emptyhash = hashlib.sha256(b'').digest()
 pennhash = hashlib.sha256(pbuf).digest()
 rgryhash = hashlib.sha256(rbuf).digest()
 
+fields = [
+    {'name': 'file', 'sha256': s_common.ehex(asdfhash), 'filename': 'file'},
+    {'name': 'zip_password', 'value': 'test'},
+]
+
 asdfretn = (8, asdfhash)
 emptyretn = (0, emptyhash)
 pennretn = (9, pennhash)
@@ -53,14 +59,28 @@ class HttpPushFile(s_httpapi.StreamHandler):
 
     async def prepare(self):
         self.gotsize = 0
+        self.byts = b''
 
     async def data_received(self, byts):
         self.gotsize += len(byts)
+        self.byts += byts
 
     async def put(self):
         assert self.gotsize == 8
         self.sendRestRetn(self.gotsize)
 
+    async def post(self):
+        args = {}
+        files = {}
+        t_httputil.parse_body_arguments(self.request.headers["Content-Type"],
+                                        self.byts, args, files)
+        item = files.get('file')[0]
+
+        assert item['body'] == b'asdfasdf'
+        assert item['filename'] == 'file'
+        assert args.get('zip_password') == [b'test']
+        self.sendRestRetn(self.gotsize)
+
 class AxonTest(s_t_utils.SynTest):
 
     async def check_blob(self, axon, fhash):
@@ -557,6 +577,37 @@ class AxonTest(s_t_utils.SynTest):
             self.eq(False, resp['ok'])
             self.isin('Axon does not contain the requested file.', resp.get('mesg'))
 
+            q = f'''
+            $fields = $lib.list(
+                $lib.dict(name=file, sha256=$sha256, filename=file),
+                $lib.dict(name=zip_password, value=test)
+            )
+            $resp = $lib.inet.http.post("https://127.0.0.1:{port}/api/v1/pushfile",
+                                        fields=$fields, ssl_verify=(0))
+            return($resp)
+            '''
+            opts = {'vars': {'sha256': s_common.ehex(sha256)}}
+            resp = await core.callStorm(q, opts=opts)
+            self.true(resp['ok'])
+            self.eq(200, resp['code'])
+
+            opts = {'vars': {'sha256': s_common.ehex(s_common.buid())}}
+            resp = await core.callStorm(q, opts=opts)
+            self.false(resp['ok'])
+            self.isin('Axon does not contain the requested file.', resp.get('err'))
+
+            async with axon.getLocalProxy() as proxy:
+                resp = await proxy.postfiles(fields, f'https://127.0.0.1:{port}/api/v1/pushfile', ssl=False)
+                self.true(resp['ok'])
+                self.eq(200, resp['code'])
+
+        conf = {'http:proxy': 'socks5://user:pass@127.0.0.1:1'}
+        async with self.getTestAxon(conf=conf) as axon:
+            async with axon.getLocalProxy() as proxy:
+                resp = await proxy.postfiles(fields, f'https://127.0.0.1:{port}/api/v1/pushfile', ssl=False)
+                self.false(resp['ok'])
+                self.isin('Can not connect to proxy 127.0.0.1:1', resp.get('err', ''))
+
     async def test_axon_tlscapath(self):
 
         with self.getTestDir() as dirn:
@@ -592,6 +643,10 @@ class AxonTest(s_t_utils.SynTest):
                 self.false(resp.get('ok'))
                 self.isin('unable to get local issuer certificate', resp.get('mesg'))
 
+                resp = await axon.postfiles(fields, url)
+                self.false(resp.get('ok'))
+                self.isin('unable to get local issuer certificate', resp.get('err'))
+
             conf = {'auth:passwd': 'root', 'tls:ca:dir': tlscadir}
             async with self.getTestAxon(dirn=dirn, conf=conf) as axon:
                 host, port = await axon.addHttpsPort(0, host='127.0.0.1')
@@ -605,3 +660,6 @@ class AxonTest(s_t_utils.SynTest):
                 url = f'https://root:root@localhost:{port}/api/v1/pushfile'
                 resp = await axon.wput(asdfhash, url)
                 self.true(resp.get('ok'))
+
+                resp = await axon.postfiles(fields, url)
+                self.true(resp.get('ok'))
