@@ -100,3 +100,28 @@ class ModelRevTest(s_tests.SynTest):
             self.len(1003, nodes)
             for node in nodes:
                 self.len(1, nodes[0].get('names'))
+
+    async def test_modelrev_0_2_6(self):
+        async with self.getRegrCore('model-0.2.6') as core:
+
+            acct = '90b3d80f8bdf9e33b4aeb46c720d3289'
+            nodes = await core.nodes(f'it:account={acct}')
+            self.len(1, nodes)
+            self.len(2, nodes[0].get('groups'))
+
+            g00 = 'd0d235109162501db9d4014a4c2cc4d9'
+            g01 = 'bf1999e8c45523bc64803e28b19a34c6'
+            nodes = await core.nodes(f'it:account={acct} [:groups=({g00}, {g01}, {g00})]')
+            self.len(1, nodes)
+            self.len(2, nodes[0].get('groups'))
+
+            url0 = "https://charlie.com/woot"
+            url1 = "https://bravo.com/woot"
+            url2 = "https://delta.com/woot"
+            url3 = "https://alpha.com/woot"
+
+            # created via: f'[it:sec:cve=CVE-2013-9999 :desc="some words" :references=({url0}, {url1}, {url2}, {url3})]'
+            nodes = await core.nodes(f'it:sec:cve=CVE-2013-9999')
+            self.eq(nodes[0].ndef[1], 'cve-2013-9999')
+            self.eq(nodes[0].get('desc'), 'some words')
+            self.eq(nodes[0].get('references'), (url3, url1, url0, url2))
