@@ -1,7 +1,6 @@
 import synapse.common as s_common
 
 import synapse.tests.utils as s_t_utils
-from synapse.tests.utils import alist
 
 class DnsModelTest(s_t_utils.SynTest):
 
@@ -65,7 +64,10 @@ class DnsModelTest(s_t_utils.SynTest):
                     'server': 'udp://5.6.7.8:53',
                     'reply:code': 0,
                 }
-
+                expected_nodes = (
+                    ('inet:server', 'udp://5.6.7.8:53'),
+                    ('inet:fqdn', 'vertex.link'),
+                )
                 node = await snap.addNode('inet:dns:request', '*', props)
                 req_ndef = node.ndef
                 self.eq(node.get('time'), 1514764800000)
@@ -76,7 +78,7 @@ class DnsModelTest(s_t_utils.SynTest):
                 self.eq(node.get('query:name:fqdn'), 'vertex.link')
                 self.eq(node.get('query:type'), 255)
                 self.none(node.get('query:client'))
-                self.nn(await snap.getNodeByNdef(('inet:server', 'udp://5.6.7.8:53')))
+                await self.checkNodes(core, expected_nodes)
 
                 # Ensure some remaining inet:dns:query:name:* props are broken out
                 node = await snap.addNode('inet:dns:request', '*', {'query:name': '4.3.2.1.in-addr.arpa'})
@@ -138,6 +140,14 @@ class DnsModelTest(s_t_utils.SynTest):
                 self.eq(node.get('exe'), f'guid:{"a" * 32}')
                 self.eq(node.get('query:name'), 'notac2.someone.com')
 
+            nodes = await core.nodes('[inet:dns:request=(test,) :query:name="::ffff:8.7.6.5"]')
+            self.len(1, nodes)
+            expected_nodes = (
+                ('inet:ipv4', 0x08070605),
+                ('inet:ipv6', '::ffff:8.7.6.5'),
+            )
+            await self.checkNodes(core, expected_nodes)
+
             # DNS queries can be quite complex or awkward since the protocol
             # allows for nearly anything to be asked about. This can lead to
             # pivots with non-normable data.
